Anteroom

### Settings

Theme
Model
System Prompt

### New Project

Name
Instructions These instructions are prepended to the global system prompt for all conversations in this project.
Model (optional)
Override the default model for conversations in this project.

### Add Database

Database Name Letters, numbers, hyphens, underscores only.
Database Path
File will be created if it doesn't exist.

### Rewind Conversation

Go back to this point in the conversation?

### MCP Servers

AI service not configured. Please set up your `~/.anteroom/config.yaml`.

You are offline. Reconnecting when network is available...

## Welcome to the Anteroom

Your connection is secure. How may I assist you today?

Tips:

- Enter to send, Shift+Enter for new line
- Ctrl+Shift+N for new conversation
- Cmd/Ctrl+K for command palette
- Escape to stop AI response

Untitled